@@ -206,9 +206,15 @@ bool AudioAnalysis::parseFileTagCodec(DMusic::MediaMeta &meta)
     qCDebug(dmMusic) << "Audio length detected:" << meta.length << "ms for file:" << meta.localPath;
 
     bool encode = true;
+#if TAGLIB_MAJOR_VERSION > 1 || (TAGLIB_MAJOR_VERSION == 1 && TAGLIB_MINOR_VERSION >= 11)
     encode &= tag->title().isEmpty() ? true : tag->title().isLatin1();
     encode &= tag->artist().isEmpty() ? true : tag->artist().isLatin1();
     encode &= tag->album().isEmpty() ? true : tag->album().isLatin1();
+#else
+    encode &= tag->title().isNull() ? true : tag->title().isLatin1();
+    encode &= tag->artist().isNull() ? true : tag->artist().isLatin1();
+    encode &= tag->album().isNull() ? true : tag->album().isLatin1();
+#endif
     if (encode) {
         qCDebug(dmMusic) << "Tag contains Latin1 encoded data, detecting encoding for file:" << meta.localPath;
         if (detectCodec.isEmpty()) {
@@ -480,7 +486,11 @@ void AudioAnalysis::parseMetaCover(DMusic::MediaMeta &meta)
             format_open_input(&pFormatCtx, path.toStdString().c_str(), nullptr, nullptr);
 
             if (pFormatCtx) {
+#if LIBAVFORMAT_VERSION_MAJOR < 61
                 if (pFormatCtx->iformat != nullptr && pFormatCtx->iformat->read_header(pFormatCtx) >= 0) {
+#else
+                if (avformat_find_stream_info(pFormatCtx, nullptr) >= 0) {
+#endif
                     for (unsigned int i = 0; i < pFormatCtx->nb_streams; i++) {
                         if (pFormatCtx->streams[i]->disposition & AV_DISPOSITION_ATTACHED_PIC) {
                             AVPacket pkt = pFormatCtx->streams[i]->attached_pic;
@@ -581,7 +591,11 @@ QImage AudioAnalysis::getMetaCoverImage(DMusic::MediaMeta meta)
                 return image;
             }
 
+#if LIBAVFORMAT_VERSION_MAJOR < 61
             if (pFormatCtx->iformat != nullptr && pFormatCtx->iformat->read_header(pFormatCtx) >= 0) {
+#else
+            if (avformat_find_stream_info(pFormatCtx, nullptr) >= 0) {
+#endif
                 for (unsigned int i = 0; i < pFormatCtx->nb_streams; i++) {
                     if (pFormatCtx->streams[i]->disposition & AV_DISPOSITION_ATTACHED_PIC) {
                         AVPacket pkt = pFormatCtx->streams[i]->attached_pic;
