@@ -53,22 +53,28 @@ typedef AVFrame *(*frame_alloc_function)(void);
 typedef int (*read_frame_function)(AVFormatContext *, AVPacket *);
 typedef void (*packet_unref_function)(AVPacket *);
 typedef void (*frame_free_function)(AVFrame **);
+typedef void (*packet_free_function)(AVPacket **);
 typedef int (*codec_close_function)(AVCodecContext *);
 typedef int (*codec_send_packet_function)(AVCodecContext *, const AVPacket *);
 typedef int (*codec_receive_frame_function)(AVCodecContext *, AVFrame *);
+typedef void (*codec_free_context_function)(AVCodecContext **);
 
 AudioDataDetector::AudioDataDetector(QObject *parent)
     : QThread(parent)
 {
+    qCDebug(dmMusic) << "Initializing AudioDataDetector";
     connect(this, &AudioDataDetector::audioBufferFromThread, this, &AudioDataDetector::audioBuffer, Qt::QueuedConnection);
+    qCDebug(dmMusic) << "AudioDataDetector initialized with queued connection";
 }
 
 AudioDataDetector::~AudioDataDetector()
 {
+    qCDebug(dmMusic) << "Destroying AudioDataDetector";
     m_stopFlag = true;
     while (isRunning()) {
-
+        qCDebug(dmMusic) << "Waiting for detection thread to finish";
     }
+    qCDebug(dmMusic) << "AudioDataDetector destroyed";
 }
 
 void AudioDataDetector::run()
@@ -98,7 +104,9 @@ void AudioDataDetector::run()
 
     packet_unref_function packet_unref = (packet_unref_function)DynamicLibraries::instance()->resolve("av_packet_unref", true);
     frame_free_function frame_free = (frame_free_function)DynamicLibraries::instance()->resolve("av_frame_free", true);
+    packet_free_function packet_free = (packet_free_function)DynamicLibraries::instance()->resolve("av_packet_free", true);
     codec_close_function codec_close = (codec_close_function)DynamicLibraries::instance()->resolve("avcodec_close", true);
+    codec_free_context_function codec_free_context = (codec_free_context_function)DynamicLibraries::instance()->resolve("avcodec_free_context", true);
     codec_send_packet_function codec_send_packet = (codec_send_packet_function)DynamicLibraries::instance()->resolve("avcodec_send_packet", true);
     codec_receive_frame_function codec_receive_frame = (codec_receive_frame_function)DynamicLibraries::instance()->resolve("avcodec_receive_frame", true);
 
@@ -141,6 +149,7 @@ void AudioDataDetector::run()
     AVCodec *pCodec = codec_find_decoder(pCodecCtx->codec_id);
     if (pCodec == nullptr) {
         qCCritical(dmMusic) << "Failed to find decoder for codec ID:" << pCodecCtx->codec_id << "in file:" << path;
+        codec_free_context(&pCodecCtx);
         format_close_input(&pFormatCtx);
         format_free_context(pFormatCtx);
         m_curPath.clear();
@@ -151,6 +160,7 @@ void AudioDataDetector::run()
     ret = codec_open2(pCodecCtx, pCodec, nullptr);
     if (ret < 0) {
         qCCritical(dmMusic) << "Failed to open codec for file:" << path << "error code:" << ret;
+        codec_free_context(&pCodecCtx);
         format_close_input(&pFormatCtx);
         format_free_context(pFormatCtx);
         m_curPath.clear();
@@ -166,28 +176,30 @@ void AudioDataDetector::run()
     QVector<float> curData;
 
     while (read_frame(pFormatCtx, packet) >= 0) {
-        //stop detector
         if (m_stopFlag && curData.size() > 100) {
+            qCDebug(dmMusic) << "Stop flag detected, cleaning up resources for file:" << path;
             packet_unref(packet);
+            packet_free(&packet);
             frame_free(&frame);
             codec_close(pCodecCtx);
+            codec_free_context(&pCodecCtx);
             format_close_input(&pFormatCtx);
             format_free_context(pFormatCtx);
             resample(curData, hash, true);//刷新波浪条
             m_stopFlag = false;
             m_curPath.clear();
             m_curHash.clear();
+            qCDebug(dmMusic) << "Successfully stopped detection for file:" << path;
             return;
         }
-
+        
         if (packet->stream_index == audio_stream_index) {
             int state;
             state = codec_send_packet(pCodecCtx, packet);
-            packet_unref(packet);
             if (state != 0) {
                 continue;
             }
-
+            
             state = codec_receive_frame(pCodecCtx, frame);
             if (state == 0) {
 
@@ -195,9 +207,8 @@ void AudioDataDetector::run()
                 if (path.endsWith(".ape") || path.endsWith(".APE")) {
                     for (int i = 0; (i + 1) < frame->linesize[0]; i++) {
                         auto  valDate = ((ptr[i]) << 16 | (ptr[i + 1]));
-                        //curData.append((float)valDate + qrand());
                         curData.append(static_cast<float>(valDate) + QRandomGenerator::global()->generate());
-                    }
+                }
                 } else {
                     for (int i = 0; (i + 1) < frame->linesize[0]; i += 1024) {
                         auto  valDate = ((ptr[i]) << 16 | (ptr[i + 1]));
@@ -206,11 +217,14 @@ void AudioDataDetector::run()
                 }
             }
         }
-    }
 
-    packet_unref(packet);
+        packet_unref(packet);
+    }
+    
+    packet_free(&packet);
     frame_free(&frame);
     codec_close(pCodecCtx);
+    codec_free_context(&pCodecCtx);
     format_close_input(&pFormatCtx);
     format_free_context(pFormatCtx);
     resample(curData, hash);
@@ -281,6 +295,7 @@ void AudioDataDetector::resample(const QVector<float> &buffer, const QString &ha
 
 
     if (!t_buffer.isEmpty()) {
+        qCDebug(dmMusic) << "Normalizing buffer data for hash:" << hash << "original size:" << t_buffer.size();
         auto max = *(std::max_element(std::begin(t_buffer), std::end(t_buffer)));
         for (int i = 0; i < t_buffer.size(); ++i) {
             float ft = t_buffer[i] / max;
@@ -301,7 +316,7 @@ void AudioDataDetector::resample(const QVector<float> &buffer, const QString &ha
             dir.mkdir(path);
         }
         path += QString("%1.dat").arg(hash);
-        qDebug() << "path:" << QFileInfo(path);
+        qCDebug(dmMusic) << "Writing wave cache to path:" << path;
         //write cache
         char *buf = new char[mappingbuf.size() * 4 ];
         memset(buf, 0, mappingbuf.size() * 4);
