@@ -15,6 +15,7 @@
 
 #include <DTextEncoding>
 #include "util/log.h"
+#include "util/utils.h"
 
 DCORE_USE_NAMESPACE
 
@@ -105,7 +106,7 @@ static float codecConfidenceForData(const QTextCodec *codec, const QByteArray &d
 
 LyricAnalysis::LyricAnalysis(): m_offset(0.00)
 {
-
+    qCDebug(dmMusic) << "LyricAnalysis constructor called";
 }
 
 int LyricAnalysis::getIndex(qint64 pos)
@@ -124,10 +125,14 @@ int LyricAnalysis::getIndex(qint64 pos)
 
 qint64 LyricAnalysis::getPostion(int index)
 {
-    if (index < m_allLyrics.size())
+    qCDebug(dmMusic) << "Getting position for index:" << index;
+    if (index < m_allLyrics.size()) {
+        qCDebug(dmMusic) << "Valid index, returning position:" << m_allLyrics[index].first;
         return m_allLyrics[index].first;
-    else
+    } else {
+        qCDebug(dmMusic) << "Invalid index, returning 0";
         return 0;
+    }
 }
 
 void LyricAnalysis::parseLyric(const QString &str)
@@ -168,7 +173,7 @@ QString LyricAnalysis::getFileCodec()
     QString code;
     if (!fin.open(QIODevice::ReadOnly)) {
         qCWarning(dmMusic) << "Failed to open file for codec detection:" << m_filePath;
-        return code;
+        return QTextCodec::codecForLocale()->name();
     }
 
     QByteArray data = fin.readAll();
@@ -179,15 +184,39 @@ QString LyricAnalysis::getFileCodec()
         return QTextCodec::codecForLocale()->name();
     }
 
+    // 1. 首先检测UTF BOM标记
     if (QTextCodec *c = QTextCodec::codecForUtfText(data, nullptr)) {
-        qCDebug(dmMusic) << "Detected UTF codec:" << c->name();
+        qCDebug(dmMusic) << "Detected UTF codec with BOM:" << c->name();
         return c->name();
     }
 
     bool isOK = false;
     QByteArray encode = DTextEncoding::detectFileEncoding(m_filePath, &isOK);
-    qCDebug(dmMusic) << "Detected file encoding:" << encode << "success:" << isOK;
-    return encode;
+    qCDebug(dmMusic) << "DTK detected file encoding:" << encode << "success:" << isOK;
+    
+    // 使用更准确的Utils检测作为主要方法
+    QStringList detectedEncodings = Utils::detectEncodings(data);
+    if (!detectedEncodings.isEmpty()) {
+        // 验证检测到的编码是否被QTextCodec支持
+        for (const QString &encoding : detectedEncodings) {
+            QTextCodec *codec = QTextCodec::codecForName(encoding.toLatin1());
+            if (codec != nullptr) {
+                qCDebug(dmMusic) << "Utils detected encodings:" << detectedEncodings << "using validated:" << encoding;
+                return encoding;
+            } else {
+                qCWarning(dmMusic) << "Detected encoding not supported by QTextCodec:" << encoding;
+            }
+        }
+        qCWarning(dmMusic) << "No supported encoding found in Utils detection results:" << detectedEncodings;
+    }
+    
+    // 如果Utils检测失败或编码不支持，回退到DTK结果
+    if (isOK && !encode.isEmpty()) {
+        return encode;
+    }
+    
+    // 最后回退到本地编码
+    return QTextCodec::codecForLocale()->name();
 }
 
 void LyricAnalysis::setFromFile(const QString &filePath)
@@ -212,15 +241,24 @@ void LyricAnalysis::setFromFile(const QString &filePath)
 QVector<QPair<qint64, QString> > LyricAnalysis::allLyrics()
 {
     qCDebug(dmMusic) << "Returning all lyrics, count:" << m_allLyrics.size();
+    if (m_allLyrics.isEmpty()) {
+        qCDebug(dmMusic) << "Lyrics list is empty";
+    }
     return m_allLyrics;
 }
 
 QString LyricAnalysis::getLineAt(int index)
 {
+    qCDebug(dmMusic) << "Getting line at index:" << index;
+    if (index < 0 || index >= m_allLyrics.size()) {
+        qCDebug(dmMusic) << "Invalid index, returning empty string";
+        return QString();
+    }
     return m_allLyrics[index].second;
 }
 
 int LyricAnalysis::getCount() const
 {
+    qCDebug(dmMusic) << "Getting lyrics count:" << m_allLyrics.size();
     return m_allLyrics.count();
 }
