@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="hu" sourcelanguage="en_US">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu" sourcelanguage="en_US">
 <context>
     <name>AlbumDefaultPage</name>
     <message>
@@ -21,7 +19,7 @@
     <message>
         <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="63"/>
         <source> scan the Music directory</source>
-        <translation type="unfinished"> olvassa be a Zene könyvtárat</translation>
+        <translation> olvassa be a Zene könyvtárat</translation>
     </message>
 </context>
 <context>
@@ -260,7 +258,7 @@
     <message>
         <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="64"/>
         <source> scan the Music directory</source>
-        <translation type="unfinished"> olvassa be a Zene könyvtárat</translation>
+        <translation>Zene mappa beolvasása</translation>
     </message>
 </context>
 <context>
@@ -1383,4 +1381,4 @@
         <translation>Keresés</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
