@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_TW">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW" sourcelanguage="en_US">
 <context>
     <name>AlbumDefaultPage</name>
     <message>
@@ -160,11 +158,6 @@
         <source>Drag music files here or</source>
         <translation>拖曳歌曲文件來添加歌曲 或</translation>
     </message>
-    <message>
-        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="69"/>
-        <source> scan the Music directory</source>
-        <translation>掃描歌曲目錄</translation>
-    </message>
     <message>
         <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="99"/>
         <source>Your favorite songs will be displayed here</source>
@@ -190,6 +183,11 @@
         <source>” to add songs to the playlist</source>
         <translation>」將歌曲添加到播放列表</translation>
     </message>
+    <message>
+        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="69"/>
+        <source> scan the Music directory</source>
+        <translation>掃描歌曲目錄</translation>
+    </message>
 </context>
 <context>
     <name>AllMusicList</name>
@@ -628,6 +626,29 @@
         <translation>確定</translation>
     </message>
 </context>
+<context>
+    <name>ImportMenu</name>
+    <message>
+        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="25"/>
+        <source>Play queue</source>
+        <translation>播放佇列</translation>
+    </message>
+    <message>
+        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="40"/>
+        <source>My favorites</source>
+        <translation>我喜歡的歌曲</translation>
+    </message>
+    <message>
+        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="49"/>
+        <source>Create new playlist</source>
+        <translation>建立新歌單</translation>
+    </message>
+    <message>
+        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="52"/>
+        <source>New playlist</source>
+        <translation>建立歌單</translation>
+    </message>
+</context>
 <context>
     <name>LyricPage</name>
     <message>
@@ -704,7 +725,7 @@
         <translation>我喜歡的歌曲</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="396"/>
+        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="390"/>
         <source>All Songs</source>
         <translation>所有歌曲</translation>
     </message>
@@ -867,22 +888,22 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/music-player/main.cpp" line="139"/>
+        <location filename="../src/music-player/main.cpp" line="131"/>
         <source>Music is a local music player with beautiful design and simple functions.</source>
         <translation>音樂是一款設計美觀，功能簡潔的本機音樂播放器。</translation>
     </message>
     <message>
-        <location filename="../src/music-player/main.cpp" line="141"/>
+        <location filename="../src/music-player/main.cpp" line="133"/>
         <source>Music</source>
         <translation>音樂</translation>
     </message>
     <message>
-        <location filename="../src/music-player/main.cpp" line="151"/>
+        <location filename="../src/music-player/main.cpp" line="143"/>
         <source>Unknown album</source>
         <translation>未知專輯</translation>
     </message>
     <message>
-        <location filename="../src/music-player/main.cpp" line="151"/>
+        <location filename="../src/music-player/main.cpp" line="143"/>
         <source>Unknown artist</source>
         <translation>未知藝人</translation>
     </message>
@@ -913,37 +934,37 @@
         <translation>無搜尋結果</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="96"/>
+        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="95"/>
         <source>Search Results</source>
         <translation>搜尋結果</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="101"/>
+        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="100"/>
         <source>%1 albums - %2 songs</source>
         <translation>%1部專輯 - %2首歌曲</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="102"/>
+        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="101"/>
         <source>1 album - 1 song</source>
         <translation>1部專輯 - 1首歌曲</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="102"/>
+        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="101"/>
         <source>%1 album - %2 songs</source>
         <translation>%1部專輯 - %2首歌曲</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="121"/>
+        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="120"/>
         <source>Music</source>
         <translation>音樂</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="129"/>
+        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="128"/>
         <source>Artist</source>
         <translation>藝人</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="125"/>
+        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="124"/>
         <source>Album</source>
         <translation>專輯</translation>
     </message>
@@ -1049,97 +1070,97 @@
 <context>
     <name>Shortcut</name>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="60"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="55"/>
         <source>Play</source>
         <translation>播放</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="61"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="56"/>
         <source>Songs</source>
         <translation>歌曲</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="62"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="57"/>
         <source>Playlists</source>
         <translation>歌單</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="63"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="58"/>
         <source>Settings</source>
         <translation>設定</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="70"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="65"/>
         <source>Play/Pause</source>
         <translation>播放/暫停</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="71"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="66"/>
         <source>Previous</source>
         <translation>上一曲</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="72"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="67"/>
         <source>Next</source>
         <translation>下一曲</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="73"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="68"/>
         <source>Volume Up</source>
         <translation>音量增大</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="74"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="69"/>
         <source>Volume Down</source>
         <translation>音量減小</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="75"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="70"/>
         <source>Mute</source>
         <translation>靜音</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="78"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="73"/>
         <source>Favorite</source>
         <translation>收藏</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="79"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="74"/>
         <source>Unfavorite</source>
         <translation>取消收藏</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="80"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="75"/>
         <source>Song info</source>
         <translation>歌曲訊息</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="83"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="78"/>
         <source>New playlist</source>
         <translation>建立歌單</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="84"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="79"/>
         <source>Add music</source>
         <translation>添加音樂</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="85"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="80"/>
         <source>Rename playlist</source>
         <translation>重新命名歌單</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="86"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="81"/>
         <source>Remove from playlist</source>
         <translation>從歌單中刪除</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="89"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="84"/>
         <source>Help</source>
         <translation>幫助</translation>
     </message>
     <message>
-        <location filename="../src/music-player/util/shortcut.cpp" line="90"/>
+        <location filename="../src/music-player/util/shortcut.cpp" line="85"/>
         <source>Display shortcuts</source>
         <translation>顯示快捷鍵</translation>
     </message>
@@ -1160,22 +1181,22 @@
 <context>
     <name>SidebarMenu</name>
     <message>
-        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="26"/>
+        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="22"/>
         <source>Play</source>
         <translation>播放</translation>
     </message>
     <message>
-        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="33"/>
+        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="29"/>
         <source>Add songs</source>
         <translation>添加歌曲</translation>
     </message>
     <message>
-        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="42"/>
+        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="38"/>
         <source>Rename</source>
         <translation>重新命名</translation>
     </message>
     <message>
-        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="56"/>
+        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="52"/>
         <source>Delete</source>
         <translation>刪除</translation>
     </message>
@@ -1194,20 +1215,16 @@
     </message>
     <message>
         <location filename="../src/music-player/allItems/SortMenu.qml" line="34"/>
-        <location filename="../src/music-player/allItems/SortMenu.qml" line="41"/>
-        <location filename="../src/music-player/allItems/SortMenu.qml" line="46"/>
         <source>Date added</source>
         <translation>添加日期</translation>
     </message>
     <message>
         <location filename="../src/music-player/allItems/SortMenu.qml" line="37"/>
-        <location filename="../src/music-player/allItems/SortMenu.qml" line="47"/>
         <source>Album</source>
         <translation>專輯</translation>
     </message>
     <message>
         <location filename="../src/music-player/allItems/SortMenu.qml" line="36"/>
-        <location filename="../src/music-player/allItems/SortMenu.qml" line="42"/>
         <source>Artist</source>
         <translation>藝人</translation>
     </message>
@@ -1320,7 +1337,6 @@
     </message>
     <message>
         <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="63"/>
-        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="340"/>
         <source>Add music</source>
         <translation>添加音樂</translation>
     </message>
@@ -1365,4 +1381,4 @@
         <translation>搜尋</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
